Fix comment; image must be little-endian (assuming we are on little-endian CPUs...).
[libdcp.git] / src / dcp.h
index 55d3d705c80a38b1b7dc3ccf093ea2aed8e20e35..45ccce8875f12aed2c2941391d52d5a37a22fab3 100644 (file)
--- a/src/dcp.h
+++ b/src/dcp.h
@@ -18,7 +18,7 @@
 */
 
 /** @file  src/dcp.h
- *  @brief A class to create a DCP.
+ *  @brief A class to create or read a DCP.
  */
 
 #ifndef LIBDCP_DCP_H
@@ -47,7 +47,7 @@ class SubtitleAsset;
 class Reel;
 class CPL;
 class XMLMetadata;
-class Encryption;
+class Signer;
 class KDM;
 
 namespace parse {
@@ -67,22 +67,23 @@ public:
         *
         *  @param directory Directory containing the DCP's files.
         */
-       DCP (std::string directory);
+       DCP (boost::filesystem::path directory);
+
+       void read (bool require_mxfs = true);
 
/** Read an existing DCP's data.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents
         *  of the DCP.
-        *
-        *  @param require_mxfs true to throw an exception if MXF files are missing; setting to false
-        *  can be useful for testing, but normally it should be set to true.
         */
-       void read (bool require_mxfs = true);
+       void read_assets ();
+
+       void read_cpls (bool require_mxfs = true);
 
        /** Write the required XML files to the directory that was
         *  passed into the constructor.
         */
-       void write_xml (bool interop, XMLMetadata const &, boost::shared_ptr<Encryption> crypt = boost::shared_ptr<Encryption> ()) const;
+       void write_xml (bool interop, XMLMetadata const &, boost::shared_ptr<const Signer> signer = boost::shared_ptr<const Signer> ()) const;
 
        /** Compare this DCP with another, according to various options.
         *  @param other DCP to compare this one to.
@@ -125,10 +126,10 @@ private:
        /** Write the PKL file.
         *  @param pkl_uuid UUID to use.
         */
-       std::string write_pkl (std::string pkl_uuid, bool, XMLMetadata const &, boost::shared_ptr<Encryption>) const;
+       std::string write_pkl (std::string pkl_uuid, bool, XMLMetadata const &, boost::shared_ptr<const Signer>) const;
        
        /** Write the VOLINDEX file */
-       void write_volindex () const;
+       void write_volindex (bool) const;
 
        /** Write the ASSETMAP file.
         *  @param pkl_uuid UUID of our PKL.
@@ -145,12 +146,14 @@ private:
                std::string asset_map;
        };
 
+       Files _files;
+
        /** the directory that we are writing to */
-       std::string _directory;
+       boost::filesystem::path _directory;
        /** our CPLs */
        std::list<boost::shared_ptr<CPL> > _cpls;
 
-       std::list<boost::shared_ptr<const parse::AssetMap> > _asset_maps;
+       std::list<PathAssetMap> _asset_maps;
 };
 
 }
@@ -67,22 +67,23 @@ public:
 
-       /** Read an existing DCP's data.
+       /** Read an existing DCP's assets.
         *
         *  The DCP's XML metadata will be examined, and you can then look at the contents